package com.datacloudsec.utils;

import com.datacloudsec.utils.ObjectUtil;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.lang.StringUtils;

public class DateUtil {

   public static String time2Str(Long t) {
      StringBuffer buf = new StringBuffer();
      if(t.longValue() >= 86400000L) {
         buf.append(t.longValue() / 86400000L);
         buf.append("天");
         t = Long.valueOf(t.longValue() % 86400000L);
      }

      if(t.longValue() >= 3600000L) {
         buf.append(t.longValue() / 3600000L);
         buf.append("时");
         t = Long.valueOf(t.longValue() % 3600000L);
      }

      if(t.longValue() >= 60000L) {
         buf.append(t.longValue() / 60000L);
         buf.append("分");
         t = Long.valueOf(t.longValue() % 60000L);
      }

      if(t.longValue() >= 1000L) {
         buf.append(t.longValue() / 1000L);
         buf.append("秒");
      }

      return buf.toString();
   }

   public static Map getDistanceTimes(String str1, String str2) throws Exception {
      SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
      Date one = df.parse(str1);
      Date two = df.parse(str2);
      long day = 0L;
      long hour = 0L;
      long min = 0L;
      long sec = 0L;
      long time1 = one.getTime();
      long time2 = two.getTime();
      long diff = time2 - time1;
      day = diff / 86400000L;
      hour = diff / 3600000L - day * 24L;
      min = diff / 60000L - day * 24L * 60L - hour * 60L;
      sec = diff / 1000L - day * 24L * 60L * 60L - hour * 60L * 60L - min * 60L;
      HashMap times = new HashMap();
      times.put("day", Long.valueOf(day));
      times.put("hour", Long.valueOf(hour));
      times.put("min", Long.valueOf(min));
      times.put("sec", Long.valueOf(sec));
      return times;
   }

   public static String getEndTime(String format, String startTime, String interval) throws Exception {
      SimpleDateFormat df = new SimpleDateFormat(format);
      Date one = df.parse(startTime);
      long time = one.getTime();
      String[] interArr = interval.split(":");
      if(interArr.length == 2) {
         time += (long)('\uea60' * ObjectUtil.getInt(interArr[1], 0));
         time += (long)(3600000 * ObjectUtil.getInt(interArr[0], 0));
      } else if(interArr.length == 3) {
         time += (long)('\uea60' * ObjectUtil.getInt(interArr[2], 0));
         time += (long)(3600000 * ObjectUtil.getInt(interArr[1], 0));
         time += (long)(86400000 * ObjectUtil.getInt(interArr[0], 0));
      }

      return (new SimpleDateFormat("yyyy-MM-dd HH:mm:ss")).format(new Date(time));
   }

   public static String getIntervalTime(String format, String startTime, String endTime) throws Exception {
      if(!StringUtils.isBlank(startTime) && !StringUtils.isBlank(endTime)) {
         SimpleDateFormat df = new SimpleDateFormat(StringUtils.isBlank(format)?"yyyy-MM-dd HH:mm:ss":format);
         long one = df.parse(startTime).getTime();
         long two = df.parse(endTime).getTime();
         long time = two - one;
         int days = (new Double(Math.floor((double)(time / 86400000L)))).intValue();
         long leave1 = time % 86400000L;
         int hours = (new Double(Math.floor((double)(leave1 / 3600000L)))).intValue();
         long leave2 = leave1 % 3600000L;
         int minutes = (new Double(Math.floor((double)(leave2 / 60000L)))).intValue();
         long leave3 = leave2 % 60000L;
         int seconds = (new Double((double)Math.round((float)(leave3 / 1000L)))).intValue();
         StringBuilder timeStr = new StringBuilder();
         if(days > 0) {
            timeStr.append(days + "天");
         }

         if(hours > 0) {
            timeStr.append(hours + "小时");
         }

         if(minutes > 0) {
            timeStr.append(minutes + "分");
         }

         if(seconds > 0) {
            timeStr.append(seconds + "秒");
         }

         return timeStr.toString();
      } else {
         return null;
      }
   }

   public static void main(String[] args) throws Exception {
      System.out.println(getDistanceTimes("2018-01-03 16:43:55", (new SimpleDateFormat("yyyy-MM-dd HH:mm:ss")).format(new Date())));
      System.out.println(getEndTime("yyyy/MM/dd HH:mm:ss", "2018/6/7 15:18:14", "1:1:21"));
      System.out.println(getIntervalTime("yyyy-MM-dd HH:mm:ss", "2018-6-25 09:31:26", "2018-6-25 09:31:33"));
   }
}
